==> knative-model-5.2.1-sources.jar: annotations/io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaBindingFluent.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface KafkaBindingFluent<A extends KafkaBindingFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public KafkaBindingFluent.MetadataNested<A> withNewMetadata();
    public KafkaBindingFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public KafkaBindingFluent.MetadataNested<A> editMetadata();
    public KafkaBindingFluent.MetadataNested<A> editOrNewMetadata();
    public KafkaBindingFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public KafkaBindingSpec getSpec();
    public KafkaBindingSpec buildSpec();
    public A withSpec(KafkaBindingSpec spec);
    public Boolean hasSpec();
    public KafkaBindingFluent.SpecNested<A> withNewSpec();
    public KafkaBindingFluent.SpecNested<A> withNewSpecLike(KafkaBindingSpec item);
    public KafkaBindingFluent.SpecNested<A> editSpec();
    public KafkaBindingFluent.SpecNested<A> editOrNewSpec();
    public KafkaBindingFluent.SpecNested<A> editOrNewSpecLike(KafkaBindingSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public KafkaBindingStatus getStatus();
    public KafkaBindingStatus buildStatus();
    public A withStatus(KafkaBindingStatus status);
    public Boolean hasStatus();
    public KafkaBindingFluent.StatusNested<A> withNewStatus();
    public KafkaBindingFluent.StatusNested<A> withNewStatusLike(KafkaBindingStatus item);
    public KafkaBindingFluent.StatusNested<A> editStatus();
    public KafkaBindingFluent.StatusNested<A> editOrNewStatus();
    public KafkaBindingFluent.StatusNested<A> editOrNewStatusLike(KafkaBindingStatus item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<KafkaBindingFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaBindingSpecFluent<KafkaBindingFluent.SpecNested<N>> {

            public N and();
            public N endSpec();    }


    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaBindingStatusFluent<KafkaBindingFluent.StatusNested<N>> {

            public N and();
            public N endStatus();    }


}

==> knative-model-5.3.0-sources.jar: annotations/io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaBindingFluent.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface KafkaBindingFluent<A extends KafkaBindingFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public KafkaBindingFluent.MetadataNested<A> withNewMetadata();
    public KafkaBindingFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public KafkaBindingFluent.MetadataNested<A> editMetadata();
    public KafkaBindingFluent.MetadataNested<A> editOrNewMetadata();
    public KafkaBindingFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public KafkaBindingSpec getSpec();
    public KafkaBindingSpec buildSpec();
    public A withSpec(KafkaBindingSpec spec);
    public Boolean hasSpec();
    public KafkaBindingFluent.SpecNested<A> withNewSpec();
    public KafkaBindingFluent.SpecNested<A> withNewSpecLike(KafkaBindingSpec item);
    public KafkaBindingFluent.SpecNested<A> editSpec();
    public KafkaBindingFluent.SpecNested<A> editOrNewSpec();
    public KafkaBindingFluent.SpecNested<A> editOrNewSpecLike(KafkaBindingSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public KafkaBindingStatus getStatus();
    public KafkaBindingStatus buildStatus();
    public A withStatus(KafkaBindingStatus status);
    public Boolean hasStatus();
    public KafkaBindingFluent.StatusNested<A> withNewStatus();
    public KafkaBindingFluent.StatusNested<A> withNewStatusLike(KafkaBindingStatus item);
    public KafkaBindingFluent.StatusNested<A> editStatus();
    public KafkaBindingFluent.StatusNested<A> editOrNewStatus();
    public KafkaBindingFluent.StatusNested<A> editOrNewStatusLike(KafkaBindingStatus item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<KafkaBindingFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaBindingSpecFluent<KafkaBindingFluent.SpecNested<N>> {

            public N and();
            public N endSpec();    }


    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaBindingStatusFluent<KafkaBindingFluent.StatusNested<N>> {

            public N and();
            public N endStatus();    }


}
